@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -15,7 +15,7 @@
 // You should have received a copy of the GNU General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-#include <mobius/crypt/hash_sha1.h>
+#include "hash_sha1.h"
 
 namespace mobius
 {
@@ -29,9 +29,7 @@ static constexpr std::uint32_t B_VALUE = 0xefcdab89;
 static constexpr std::uint32_t C_VALUE = 0x98badcfe;
 static constexpr std::uint32_t D_VALUE = 0x10325476;
 static constexpr std::uint32_t E_VALUE = 0xc3d2e1f0;
-
-//! \brief block size = 64 bytes (512 bits) - RFC 3174 - section 4
-static constexpr int BLOCK_SIZE = 64;
+static constexpr std::uint32_t BLOCK_SIZE = 64;  // (RFC 3174 - section 4)
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief rotate left a 32-bit value
@@ -63,9 +61,8 @@ hash_sha1::hash_sha1 () noexcept
 //! \brief reset hash value
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha1::reset () noexcept
+hash_sha1::_reset () noexcept
 {
-  hash_block::reset ();
   a_ = A_VALUE;
   b_ = B_VALUE;
   c_ = C_VALUE;
@@ -81,7 +78,7 @@ hash_sha1::reset () noexcept
 //! \see http://software.intel.com/en-us/articles/improving-the-performance-of-the-secure-hash-algorithm-1/
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 void
-hash_sha1::update_block (const mobius::bytearray& data) noexcept
+hash_sha1::_update_block (const mobius::bytearray& data) noexcept
 {
   std::uint32_t a = a_;
   std::uint32_t b = b_;
@@ -806,9 +803,11 @@ hash_sha1::update_block (const mobius::bytearray& data) noexcept
 // The final block is padded with a 1 bit, \0 bytes and a 64-bit value
 // representing the message size in bits.
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-const mobius::bytearray
-hash_sha1::evaluate (const mobius::bytearray& data)
+mobius::bytearray
+hash_sha1::_evaluate (const mobius::bytearray& data)
 {
+  hash_sha1 tmp (*this);
+
   // represent message size in bits as a bytearray
   std::uint64_t bits = ((size_ + data.size ()) << 3);
 
@@ -832,11 +831,11 @@ hash_sha1::evaluate (const mobius::bytearray& data)
       mobius::bytearray padding (64 - data.size ());
       padding.fill (0);
       padding[0] = 0x80;                // 1st bit = "1"
-      update_block (data + padding);
+      _update_block (data + padding);
 
       mobius::bytearray padding2 (56);
       padding2.fill (0);
-      update_block (padding2 + dsize);
+      _update_block (padding2 + dsize);
     }
 
   // otherwise, generate just one block:
@@ -846,11 +845,11 @@ hash_sha1::evaluate (const mobius::bytearray& data)
       mobius::bytearray padding (56 - data.size ());
       padding.fill (0);
       padding[0] = 0x80;                // 1st bit = "1"
-      update_block (data + padding + dsize);
+      _update_block (data + padding + dsize);
     }
 
   // build digest
-  mobius::bytearray digest =
+  mobius::bytearray digest
   {
     std::uint8_t (a_ >> 24),
     std::uint8_t (a_ >> 16),
@@ -874,8 +873,9 @@ hash_sha1::evaluate (const mobius::bytearray& data)
     std::uint8_t (e_)
   };
 
+  *this = tmp;
   return digest;
 }
 
-} // crypt namespace
-} // mobius namespace
+} // namespace crypt
+} // namespace mobius
