@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -19,6 +19,7 @@
 #include <mobius/core/application.h>
 #include <mobius/database/connection_pool.h>
 #include <mobius/string_functions.h>
+#include <mutex>
 #include <string>
 #include <tuple>
 #include <set>
@@ -35,7 +36,6 @@
 // transaction.commit ();                        // only when have modified data
 // connection.release ();                        // only when running in a new thread!!!
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-
 namespace mobius
 {
 namespace turing
@@ -50,39 +50,19 @@ static const std::string NT_NULL = "31d6cfe0d16ae931b73c59d7e0c089c0";
 static constexpr int SCHEMA_VERSION = 2;
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Turing data structure
+// Module data
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static class data
-{
-public:
-  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  //! \brief Get connection pool
-  //! \return Connection pool object
-  // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  mobius::database::connection_pool
-  get_pool ()
-  {
-    if (!data_loaded_)
-      {
-        _load_data ();
-        data_loaded_ = true;
-      }
+//! \brief connection pool
+static mobius::database::connection_pool pool_;
 
-    return pool_;
-  }
-
-private:
-  mobius::database::connection_pool pool_;
-  bool data_loaded_ = false;
-
-  void _load_data ();
-} data_;
+//! \brief flag object loaded
+static std::once_flag is_loaded_;
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Load data structure
+//! \brief Load module data
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-void
-data::_load_data ()
+static void
+_init ()
 {
   mobius::core::application app;
   pool_.set_path (app.get_config_path ("turing.sqlite"));
@@ -104,8 +84,6 @@ data::_load_data ()
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // set schema version
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  int current_version = 1;
-
   auto stmt = db.new_statement (
                 "SELECT value "
                   "FROM meta "
@@ -113,7 +91,7 @@ data::_load_data ()
 
   if (stmt.fetch_row ())
     {
-      current_version = stmt.get_column_int (0);
+      int current_version = stmt.get_column_int (0);
 
       if (current_version < SCHEMA_VERSION)
         {
@@ -205,14 +183,11 @@ data::_load_data ()
 } // namespace
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief Get database object for current thread
-//! \return database object
+//! \brief Constructor
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-mobius::database::database
-get_database ()
+turing::turing ()
 {
-  auto pool = data_.get_pool ();
-  return pool.get_database ();
+  std::call_once (is_loaded_, _init);
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -222,8 +197,7 @@ get_database ()
 mobius::database::connection
 turing::new_connection ()
 {
-  auto pool = data_.get_pool ();
-  return pool.acquire ();
+  return pool_.acquire ();
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -233,7 +207,7 @@ turing::new_connection ()
 mobius::database::transaction
 turing::new_transaction ()
 {
-  auto db = get_database ();
+  auto db = pool_.get_database ();
   return db.new_transaction ();
 }
 
@@ -247,7 +221,7 @@ turing::has_hash (
     const std::string& hash_type,
     const std::string& hash_value)
 {
-  auto db = get_database ();
+  auto db = pool_.get_database ();
 
   auto stmt = db.new_statement (
                 "SELECT 1 "
@@ -297,7 +271,7 @@ turing::set_hash (
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // insert hash
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  auto db = get_database ();
+  auto db = pool_.get_database ();
 
   auto stmt = db.new_statement (
                 "INSERT INTO hash "
@@ -364,7 +338,7 @@ turing::get_hash_password (
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   else
     {
-      auto db = get_database ();
+      auto db = pool_.get_database ();
 
       auto stmt = db.new_statement (
                 "SELECT password "
@@ -391,7 +365,7 @@ turing::get_hash_password (
 void
 turing::remove_hashes ()
 {
-  auto db = get_database ();
+  auto db = pool_.get_database ();
   auto stmt = db.new_statement ("DELETE FROM hash");
 
   stmt.execute ();
@@ -404,7 +378,7 @@ turing::remove_hashes ()
 turing::hashlist_type
 turing::get_hashes () const
 {
-  auto db = get_database ();
+  auto db = pool_.get_database ();
 
   auto stmt = db.new_statement (
                 "SELECT type, value, password "
