@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -21,6 +21,7 @@
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 #include <pymobius.h>
+#include <pylist.h>
 #include "case.h"
 #include "module.h"
 #include "application.h"
@@ -474,7 +475,61 @@ static void
 tp_dealloc (model_case_o *self)
 {
   delete self->obj;
-  self->ob_type->tp_free ((PyObject*) self);
+  Py_TYPE (self)->tp_free ((PyObject*) self);
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>case</i> tp_richcompare
+//! \param py_a Case Object
+//! \param py_b Case Object
+//! \param op Operation
+//! \return Either Py_True or Py_False
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_richcompare (PyObject *py_a, PyObject *py_b, int op)
+{
+  PyObject *ret = nullptr;
+
+  if (!pymobius_model_case_check (py_a) || !pymobius_model_case_check (py_b))
+    ret = mobius::py::py_false ();
+
+  else
+    {
+      auto a = * (reinterpret_cast <model_case_o *>(py_a)->obj);
+      auto b = * (reinterpret_cast <model_case_o *>(py_b)->obj);
+      bool rc = false;
+
+      switch (op)
+        {
+        case Py_EQ:
+          rc = (a == b);
+          break;
+
+        case Py_NE:
+          rc = (a != b);
+          break;
+
+        case Py_LT:
+          rc = (a < b);
+          break;
+
+        case Py_LE:
+          rc = (a <= b);
+          break;
+
+        case Py_GT:
+          rc = (a > b);
+          break;
+
+        case Py_GE:
+          rc = (a >= b);
+          break;
+        }
+
+      ret = rc ? mobius::py::py_true () : mobius::py::py_false ();
+    }
+
+  return ret;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -505,7 +560,7 @@ PyTypeObject model_case_t =
   "Case class",                            		// tp_doc
   0,                                       		// tp_traverse
   0,                                       		// tp_clear
-  0,                                       		// tp_richcompare
+  tp_richcompare,                              		// tp_richcompare
   0,                                       		// tp_weaklistoffset
   0,                                       		// tp_iter
   0,                                       		// tp_iternext
@@ -529,4 +584,5 @@ PyTypeObject model_case_t =
   0,                                       		// tp_weaklist
   0,                                       		// tp_del
   0,                                       		// tp_version_tag
+  0,                                       		// tp_finalize
 };
