@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -15,16 +15,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-import decoder_arestra
-import decoder_phashidx_dat
-import decoder_shareh_dat
-import decoder_sharel_dat
-import decoder_tempdl_phash_dat
-import decoder_tempdl_pbthash_dat
-import decoder_torrenth_dat
 import pymobius.p2p
 import mobius
 import collections
+from . import decoder_arestra
+from . import decoder_phashidx_dat
+from . import decoder_shareh_dat
+from . import decoder_sharel_dat
+from . import decoder_tempdl_phash_dat
+from . import decoder_tempdl_pbthash_dat
+from . import decoder_torrenth_dat
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Constants
@@ -150,7 +150,7 @@ class profile (object):
       # TorrentH.dat
       elif fname == 'torrenth.dat':
         entries = decoder_torrenth_dat.decode (f)
-        
+
         if entries != None:
           self.__torrenth += entries
           pymobius.p2p.set_handled (self.__item, f)
@@ -182,7 +182,7 @@ class profile (object):
       # PHashIdx.dat
       elif fname in ('phashidx.dat', 'phashidxtemp.dat', 'tempphash.dat'):
         entries = decoder_phashidx_dat.decode (f)
-        
+
         if entries != None:
           self.__phashidx.update ((e.hash_sha1, e) for e in entries)
           pymobius.p2p.set_handled (self.__item, f)
@@ -234,7 +234,7 @@ class profile (object):
 
       else:
         mobius.core.logf ('p2p.ares: Unhandled Data/TempDL/%s file' % f.name)
-          
+
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Retrieve data from My Shared Folder
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -259,7 +259,7 @@ class profile (object):
 
         if entry:
           self.__arestra[entry.hash_sha1] = entry
-  
+
     # set is_normalized false
     self.__is_normalized = False
 
@@ -269,7 +269,7 @@ class profile (object):
   def __normalize (self):
     self.__generate_remote_files ()
     self.__generate_local_files ()
-    
+
     # release old data
     self.__sharel = None
     self.__shareh = None
@@ -288,7 +288,7 @@ class profile (object):
     self.__remote_files = []
 
     # add remote files from ___ARESTRA___
-    for entry in self.__arestra.itervalues ():
+    for entry in self.__arestra.values ():
       for source in entry.sources:
         f = remote_file ()
         f.name = entry.name
@@ -332,7 +332,7 @@ class profile (object):
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_local_files_from_sharel (self):
 
-    for entry in self.__sharel.itervalues ():
+    for entry in self.__sharel.values ():
       f = local_file ()
       f.size = entry.size
       f.hash_sha1 = entry.hash_sha1
@@ -357,7 +357,7 @@ class profile (object):
       f.metadata['sharel_path'] = entry.sharel_path
       f.metadata['sharel_creation_time'] = entry.sharel_creation_time
       f.metadata['sharel_last_modification_time'] = entry.sharel_last_modification_time
-  
+
       self.__local_files.append (f)
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -393,7 +393,7 @@ class profile (object):
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_local_files_from_shareh (self):
 
-    for entry in self.__shareh.itervalues ():
+    for entry in self.__shareh.values ():
       f = local_file ()
       f.size = entry.size
       f.hash_sha1 = entry.hash_sha1
@@ -426,7 +426,7 @@ class profile (object):
 
     for f in self.__local_files:
       arestra_entry = self.__arestra.get (f.hash_sha1, None)
-      
+
       if arestra_entry:
         f.path = f.path or arestra_entry.path
         f.name = f.name or arestra_entry.name
@@ -446,10 +446,10 @@ class profile (object):
   # @brief Add local files from ___ARESTRA___ files
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_local_files_from_arestra (self):
-    for entry in self.__arestra.itervalues ():
+    for entry in self.__arestra.values ():
 
       if entry.size > 0:
-        pct_progress = float (entry.progress) * 100.0 / float (entry.size) 
+        pct_progress = float (entry.progress) * 100.0 / float (entry.size)
       else:
         pct_progress = 0.0
 
@@ -491,11 +491,11 @@ class profile (object):
 
     for f in self.__local_files:
       entry = self.__phashidx.pop (f.hash_sha1, None)
-      
+
       if entry:
         f.flag_downloaded = STATE_YES
         f.flag_completed = STATE_YES
-        
+
         if f.size != -1:
           f.metadata['bytes_downloaded'] = f.size
 
@@ -513,16 +513,16 @@ class profile (object):
 
     for f in self.__local_files:
       entry = self.__phash.pop (f.hash_sha1, None)
-      
+
       if entry:
         progress = sum (p.progress for p in entry.pieces)
         pieces_done = [p for p in entry.pieces if p.done]
-        
+
         if f.flag_downloaded != STATE_YES and progress > 0:
           f.flag_downloaded = STATE_YES
 
         f.metadata['pieces'] = len (entry.pieces)
-        
+
         if pieces_done:
           f.metadata['piece_size'] = '%d bytes' % max (p.progress for p in pieces_done)
 
@@ -550,7 +550,7 @@ class profile (object):
         # flag_downloaded
         if entry.bytes_downloaded > 0:
           f.flag_downloaded = STATE_YES
-            
+
         elif f.flag_downloaded == STATE_UNKNOWN:
           f.flag_downloaded = STATE_NO
 
@@ -564,7 +564,7 @@ class profile (object):
         # flag_completed
         if entry.bytes_downloaded == entry.size:
           f.flag_completed = STATE_YES
-            
+
         elif f.flag_completed == STATE_UNKNOWN:
           f.flag_completed = STATE_NO
 
@@ -572,7 +572,7 @@ class profile (object):
         if entry.num_files == 1:
           f.metadata['bytes_downloaded'] = entry.bytes_downloaded
           f.metadata['bytes_uploaded'] = entry.bytes_uploaded
-          
+
         elif entry.bytes_downloaded == entry.size:
           f.metadata['bytes_downloaded'] = ef.size
 
@@ -592,14 +592,14 @@ class profile (object):
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __add_local_files_from_pbthash (self):
 
-    for entry, ef in self.__pbthash.itervalues ():
+    for entry, ef in self.__pbthash.values ():
       f = local_file ()
       f.app_id = 'ares'
       f.app = 'Ares Galaxy'
       f.size = ef.size
       f.name = ef.name
       f.path = ef.path
-    
+
       # flags
       flag_checked = all (p for p in entry.pieces if p.flag_checked)
 
@@ -623,7 +623,7 @@ class profile (object):
 
       elif entry.bytes_uploaded > 0 and entry.num_files == 1:
         f.flag_uploaded = STATE_YES
-        
+
       # metadata
       f.metadata['torrent_hash_sha1'] = entry.hash_sha1.upper ()
       f.metadata['torrent_piece_length'] = '%d bytes' % entry.piece_length
@@ -637,7 +637,7 @@ class profile (object):
       f.metadata['pbthash_last_modification_time'] = entry.pbthash_last_modification_time
 
       self.__local_files.append (f)
-      
+
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Add local files from TorrentH.dat file
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
