@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022,2023,2024 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -437,7 +437,7 @@ def get_sam_key (registry):
       md5.update (syskey)
       md5.update (b'0123456789012345678901234567890123456789\0')
 
-      rc4 = mobius.crypt.cipher ("rc4", md5.get_digest ())
+      rc4 = mobius.crypt.new_cipher_stream ("rc4", md5.get_digest ())
       sam_key = rc4.encrypt (f[0x80:0xa0])[:16]
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -448,8 +448,8 @@ def get_sam_key (registry):
       struct_revision, struct_size, check_len, data_len, salt = struct.unpack ('<IIII16s', f[0x68:0x88])
       data = f[0x88:0x88 + data_len]            # followed by check
 
-      aes = mobius.crypt.cipher ("aes", syskey, "cbc", salt)
-      sam_key = aes.decrypt (data)[:16]         # AES-128 (16 bytes key)
+      c = mobius.crypt.new_cipher_cbc ("aes", syskey, salt)
+      sam_key = c.decrypt (data)[:16]         # AES-128 (16 bytes key)
 
     else:
       mobius.core.logf ('DEV Domains\\Account\\F unknown revision: %08x' % revision)
@@ -579,7 +579,7 @@ class user_account (object):
       md5.update (rid_data)
       md5.update (ntlm_str)
 
-      rc4 = mobius.crypt.cipher ("rc4", md5.get_digest ())
+      rc4 = mobius.crypt.new_cipher_stream ("rc4", md5.get_digest ())
       obfkey = rc4.decrypt (data[4:])
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -592,8 +592,8 @@ class user_account (object):
       if data_size:
         salt = data[8:24]
         hdata = data[24:24 + data_size]
-        aes = mobius.crypt.cipher ("aes", self.__sam_key, "cbc", salt)
-        obfkey = aes.decrypt (hdata)
+        c = mobius.crypt.new_cipher_cbc ("aes", self.__sam_key, salt)
+        obfkey = c.decrypt (hdata)
 
       else:
         obfkey = b''
@@ -614,8 +614,8 @@ class user_account (object):
       h.type = htype
       h.is_current = is_current
 
-      des1 = mobius.crypt.cipher ("des", key1)
-      des2 = mobius.crypt.cipher ("des", key2)
+      des1 = mobius.crypt.new_cipher_ecb ("des", key1)
+      des2 = mobius.crypt.new_cipher_ecb ("des", key2)
       h.value = des1.decrypt (obfkey[i:i + 8]) + des2.decrypt (obfkey[i + 8:i + NTLM_HASH_SIZE])
       hashes.append (h)
 
